.. |sb| raw:: html

   <strike>

.. |se| raw:: html

   </strike>

Future Work
=================================

We have built PypKa with a clear focus on three things:

* Usability

* Speed

* Accuracy


Naturaly our development path also reflects these concerns.

=================================
Greater Usability
=================================

- Provide a Webserver Interface and platform

- More in-deepth user documentation
  
- Improve code-level documentation

- Create a series of tutorials

- Implement a proper logging system to give the users more info

- Expand our test suite

=================================
Faster Calculations
=================================

- Allow the titration of a single site and all titrable residues within a cutoff radius

- Implement an asynchronous algorithm to manage the Monte Carlo
  runs with a dynamic step and automatic pH range

- |sb| Porting the code to python3 |se|

=================================
Accuracy Improvement
=================================

- |sb| Support structures with multiple chains |se|

- Improve preprocessing guess of tautomer position guess

- |sb| Extensive benchmark and further optimization of parameters |se|

- Support for CHARMM, AMBER and PARSE based charges and radii

- Support more lipids

- |sb| Support Nucleic Acids |se|
